@@ -36,3 +36,11 @@ class MachineNotRunningException(RcException):
 
 class RunException(RcException):
     pass
+
+
+class MachineChangeTypeException(RcException):
+    pass
+
+
+class MachineNotReadyException(RcException):
+    pass
